# python chromadb_query.py "question" "e:/search.json" "e:/chromadb/dbname1" "collection_name" 3
import sys
import chromadb
import json
from sentence_transformers import SentenceTransformer
from chromadb.config import Settings

argvlen = len(sys.argv)
retnum = 3
if argvlen == 7:
    questionfile = sys.argv[1]
    filenameout = sys.argv[2]
    modepath = sys.argv[3]
    localdbpaht = sys.argv[4]
    collectionname = sys.argv[5]
    retnum = int(sys.argv[6])
    
    # 设置本地数据库名称（Persistent本地持久化）和表名（Collection集合）
    model = SentenceTransformer(modepath)
    CHROMA_CLIENT = chromadb.PersistentClient(
        path = localdbpaht,
        settings=chromadb.Settings(anonymized_telemetry=False)
    )
    COLLECTION = CHROMA_CLIENT.get_or_create_collection(collectionname)
    with open(questionfile, "r", encoding="utf-8") as f:
        question = f.read()
    # 读取查询的问题
    if len(question) > 0:
        #print(question)
        query_embedding = model.encode([question]).tolist()
        # Chroma检索
        results = COLLECTION.query(
	        query_embeddings=query_embedding,
            n_results = retnum
        )
        
        json_string = json.dumps(results, ensure_ascii=False)
        #print(json_string)
		# 将查询的json结果写入输出文件
        with open(filenameout, 'wb') as filewrite:
           textuft8 = json_string.encode('utf-8')
           filewrite.write(textuft8)
else:
    print("python chromadb_query.py \"e:/question.txt\" \"e:/search.json\" \"e:/chromadb/dbname1\" \"collection_name\" retnum")          

# python chromadb_query.py "question" "e:/search.json" "e:/chromadb/dbname1" "collection_name" 3


# python chromadb_clear.py "e:/chromadb/dbname" "collection_name"
import sys
import chromadb
import json
from chromadb.config import Settings

argvlen = len(sys.argv)
if argvlen == 3:
    localdbpaht = sys.argv[1]
    collectionname = sys.argv[2]
	
	# 设置本地数据库名称（Persistent本地持久化）和表名（Collection集合）
    CHROMA_CLIENT = chromadb.PersistentClient(
        path = localdbpaht,
        settings = chromadb.Settings(anonymized_telemetry=False)
    )
    COLLECTION = CHROMA_CLIENT.get_or_create_collection(collectionname)
    # 清空集合
    COLLECTION.delete(ids=COLLECTION.get()["ids"])
	# 删除整个集合
    #CHROMA_CLIENT.delete_collection(name=collectionname)
else:
    print("python chromadb_clear.py \"e:/chromadb/dbname\" \"collection_name\"")          

# python chromadb_clear.py "e:/chromadb/dbname" "collection_name"


# python chromadb_add.py "e:/insert.json" "e:/chromadb/dbname" "collection_name"
import sys
import chromadb
import json
from chromadb.config import Settings

argvlen = len(sys.argv)
print(argvlen)
if argvlen == 4:
    jsonfilename = sys.argv[1]
    localdbpath = sys.argv[2]
    collectionname = sys.argv[3]
	
	# 设置本地数据库名称（Persistent本地持久化）和表名（Collection集合）
    CHROMA_CLIENT = chromadb.PersistentClient(
        path = localdbpath,
        settings = chromadb.Settings(anonymized_telemetry=False)
    )
    COLLECTION = CHROMA_CLIENT.get_or_create_collection(
        name = collectionname,
        metadata={"hnsw:space": "cosine"}
    )
	# 加载json文件
    with open(jsonfilename, 'r', encoding='utf-8') as f:
        jsoninsert = json.load(f)
        ids = jsoninsert['ids']
        embeddings = jsoninsert['embeddings']
        documents = jsoninsert['chunks']
        metadatas = jsoninsert['metadatas']
        # 插入到数据库中
        COLLECTION.upsert(
            ids=ids,
            embeddings=embeddings,
            documents=documents,
			metadatas=metadatas)
else:
    print("python chromadb_add.py \"e:/insert.json\" \"e:/chromadb/dbname\" \"collection_name\"") 
# python chromadb_add.py "e:/insert.json" "e:/chromadb/dbname" "collection_name"
"""
# The sentences to encode
sentences = [
    "The weather is lovely today.",
    "It's so sunny outside!",
    "He drove to the stadium.",
]

# 2. Calculate embeddings by calling model.encode()
embeddings = model.encode(sentences)
print(embeddings.shape)
# [3, 384]

# 3. Calculate the embedding similarities
similarities = model.similarity(embeddings, embeddings)
# tensor([[1.0000, 0.6660, 0.1046],
#         [0.6660, 1.0000, 0.1411],
#         [0.1046, 0.1411, 1.0000]])
"""


# python txt2embeddings.py "e:/chunks.json" "e:/embeddings.json"
import sys
import json
from sentence_transformers import SentenceTransformer

#model = SentenceTransformer("E:/AI/SentenceMode/paraphrase-multilingual-MiniLM-L12-v2")

argvlen = len(sys.argv)
if argvlen == 4:
    filenametxt = sys.argv[1]
    filenameout = sys.argv[2]
    modepath = sys.argv[3]
    model = SentenceTransformer(modepath)
    with open(filenametxt, 'r', encoding='utf-8') as f:
        jsonchunks = json.load(f)
        sentences = jsonchunks['chunks']
        #print(sentences)
        embeddings = model.encode(sentences)
        #print(f"embeddings length:{len(embeddings)}")
        #print(embeddings)
        with open(filenameout, 'wb') as filewrite:
                datadic = {}
                datadic['embeddings'] = embeddings.tolist()
                #json.dump(datadic, filewrite, ensure_ascii=False)
                json_string = json.dumps(datadic)
                textuft8 = json_string.encode('utf-8')
                filewrite.write(textuft8)
                #print(embeddings.tolist())
else:
    print("python txt2embeddings.py \"e:/chunks.json\" \"e:/embeddings.json\" \"E:/AI/SentenceMode/bge-small-zh-v1.5\"")             
# python txt2embeddings.py "e:/chunks.json" "e:/embeddings.json"